"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatabasesList = void 0;
const react_1 = __importDefault(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const format_1 = require("./format");
const namespace_card_1 = require("./namespace-card");
const items_grid_1 = require("./items-grid");
const DATABASE_CARD_WIDTH = compass_components_1.spacing[6] * 4;
const DATABASE_CARD_HEIGHT = 154;
const DATABASE_CARD_LIST_HEIGHT = 118;
const DatabasesList = ({ databases, onDatabaseClick, onCreateDatabaseClick, onDeleteDatabaseClick, onRefreshClick, }) => {
    return (react_1.default.createElement(items_grid_1.ItemsGrid, { items: databases, itemType: "database", itemGridWidth: DATABASE_CARD_WIDTH, itemGridHeight: DATABASE_CARD_HEIGHT, itemListHeight: DATABASE_CARD_LIST_HEIGHT, sortBy: [
            { name: 'name', label: 'Database Name' },
            { name: 'storage_size', label: 'Storage size' },
            { name: 'collectionsLength', label: 'Collections' },
            { name: 'index_count', label: 'Indexes' },
        ], onItemClick: onDatabaseClick, onDeleteItemClick: onDeleteDatabaseClick, onCreateItemClick: onCreateDatabaseClick, onRefreshClick: onRefreshClick, renderItem: ({ item: db, onItemClick, onDeleteItemClick, viewType, ...props }) => {
            return (react_1.default.createElement(namespace_card_1.NamespaceItemCard, { id: db._id, key: db._id, name: db.name, type: "database", viewType: viewType, status: db.status, data: [
                    {
                        label: 'Storage size',
                        value: (0, format_1.compactBytes)(db.storage_size),
                        hint: `Uncompressed data size: ${(0, format_1.compactBytes)(db.data_size)}`,
                    },
                    {
                        label: 'Collections',
                        value: (0, format_1.compactNumber)(db.collectionsLength),
                        insights: db.collectionsLength >= 10000
                            ? compass_components_1.PerformanceSignals.get('too-many-collections')
                            : undefined,
                    },
                    {
                        label: 'Indexes',
                        value: (0, format_1.compactNumber)(db.index_count),
                    },
                ], onItemClick: onItemClick, onItemDeleteClick: onDeleteItemClick, ...props }));
        } }));
};
exports.DatabasesList = DatabasesList;
//# sourceMappingURL=databases.js.map