"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ItemsGrid = exports.createButton = void 0;
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const provider_1 = require("@mongodb-js/compass-logging/provider");
const use_view_type_1 = require("./use-view-type");
const use_create_1 = require("./use-create");
const use_refresh_1 = require("./use-refresh");
const row = (0, compass_components_1.css)({
    paddingLeft: compass_components_1.spacing[3],
    paddingRight: compass_components_1.spacing[3],
    paddingBottom: compass_components_1.spacing[2],
    columnGap: compass_components_1.spacing[2],
});
const container = (0, compass_components_1.css)({
    width: '100%',
    flex: 1,
    overflow: 'hidden',
    display: 'grid',
    gridTemplateRows: 'auto 1fr',
    gridTemplateColumns: '100%',
    outline: 'none',
});
const controls = (0, compass_components_1.css)({
    display: 'flex',
    padding: compass_components_1.spacing[3],
    gap: compass_components_1.spacing[2],
    flex: 'none',
});
exports.createButton = (0, compass_components_1.css)({
    whiteSpace: 'nowrap',
});
const control = (0, compass_components_1.css)({
    flex: 'none',
});
const CONTROLS_HEIGHT = compass_components_1.spacing[5] + 36;
const pushRight = (0, compass_components_1.css)({
    marginLeft: 'auto',
});
const ControlsContext = react_1.default.createContext({
    createControls: null,
    refreshControls: null,
    viewTypeControls: null,
    sortControls: null,
});
const GridControls = () => {
    const { createControls, refreshControls, viewTypeControls, sortControls } = (0, react_1.useContext)(ControlsContext);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        createControls && (react_1.default.createElement("div", { className: control, "data-testid": "create-controls" }, createControls)),
        refreshControls && (react_1.default.createElement("div", { className: control, "data-testid": "refresh-controls" }, refreshControls)),
        react_1.default.createElement("div", { className: (0, compass_components_1.cx)(control, pushRight) }, viewTypeControls),
        react_1.default.createElement("div", { className: control }, sortControls)));
};
const ItemsGrid = ({ itemType, itemGridWidth, itemGridHeight, itemListWidth = itemGridWidth, itemListHeight = itemGridHeight, items, sortBy = [], onItemClick, onDeleteItemClick, onCreateItemClick, onRefreshClick, renderItem: _renderItem, }) => {
    const { track } = (0, provider_1.useLoggerAndTelemetry)('COMPASS-DATABASES-COLLECTIONS-LIST-UI');
    const onViewTypeChange = (0, react_1.useCallback)((newType) => {
        track('Switch View Type', { view_type: newType, item_type: itemType });
    }, [itemType, track]);
    const createControls = (0, use_create_1.useCreateControls)(itemType, onCreateItemClick);
    const refreshControls = (0, use_refresh_1.useRefreshControls)(onRefreshClick);
    const [sortControls, sortState] = (0, compass_components_1.useSortControls)(sortBy);
    const [viewTypeControls, viewType] = (0, use_view_type_1.useViewTypeControls)({
        onChange: onViewTypeChange,
    });
    const sortedItems = (0, compass_components_1.useSortedItems)(items, sortState);
    const itemWidth = viewType === 'grid' ? itemGridWidth : itemListWidth;
    const itemHeight = viewType === 'grid' ? itemGridHeight : itemListHeight;
    const shouldShowControls = items.length > 0;
    const renderItem = (0, react_1.useCallback)(({ index, ...props }) => {
        const item = sortedItems[index];
        return _renderItem({
            item,
            viewType,
            onItemClick,
            onDeleteItemClick,
            ...props,
        });
    }, [_renderItem, onDeleteItemClick, onItemClick, sortedItems, viewType]);
    return (react_1.default.createElement(ControlsContext.Provider, { value: {
            createControls,
            refreshControls,
            sortControls: shouldShowControls ? sortControls : null,
            viewTypeControls: shouldShowControls ? viewTypeControls : null,
        } },
        react_1.default.createElement(compass_components_1.VirtualGrid, { itemMinWidth: itemWidth, itemHeight: itemHeight + compass_components_1.spacing[2], itemsCount: sortedItems.length, colCount: viewType === 'list' ? 1 : undefined, renderItem: renderItem, itemKey: (index) => sortedItems[index]._id, headerHeight: CONTROLS_HEIGHT, renderHeader: GridControls, classNames: {
                container,
                header: controls,
                row: row,
            }, resetActiveItemOnBlur: false, "data-testid": `${itemType}-grid` })));
};
exports.ItemsGrid = ItemsGrid;
//# sourceMappingURL=items-grid.js.map